You are viewing a plain text version of this content. The canonical link for it is here.
Posted to issues@trafficcontrol.apache.org by GitBox <gi...@apache.org> on 2018/05/08 19:19:11 UTC

[GitHub] rob05c closed pull request #2244: prevents failure of ssl files and processing of remap config params

rob05c closed pull request #2244: prevents failure of ssl files and processing of remap config params
URL: https://github.com/apache/incubator-trafficcontrol/pull/2244
 
 
   

This is a PR merged from a forked repository.
As GitHub hides the original diff on merge, it is displayed below for
the sake of provenance:

As this is a foreign pull request (from a fork), the diff is supplied
below (as it won't show otherwise due to GitHub magic):

diff --git a/traffic_ops/bin/traffic_ops_ort.pl b/traffic_ops/bin/traffic_ops_ort.pl
index f0a9af3b7..54b9d0e53 100755
--- a/traffic_ops/bin/traffic_ops_ort.pl
+++ b/traffic_ops/bin/traffic_ops_ort.pl
@@ -1292,8 +1292,9 @@ sub check_plugins {
 					{
 						($plugin_config_file) = split( /\s+/, $plugin_config_file);
 
 						# Skip parameters that start with '-', since those are probabably parameters, not config files.
 						last if $plugin_config_file =~ m/^-/; # Exit subblock.
+						last if $plugin_config_file =~ m/^proxy.config./;
 
 						( my @parts ) = split( /\//, $plugin_config_file );
 						$plugin_config_file = $parts[$#parts];
@@ -2564,10 +2565,6 @@ sub set_uri {
 		$URI = $cfg_file_tracker->{$filename}->{'url'};
 		( $log_level >> $DEBUG ) && print "DEBUG Setting external download URL.\n";
 	}
-	else {
-		( $log_level >> $ERROR ) && print "ERROR Configuration File API not found!  Please upgrade to Traffic Ops 2.2.  Unable to continue.\n";
-		exit 1;
-	}
 
 	return if (!defined($cfg_file_tracker->{$filename}->{'fname-in-TO'}));
 


 

----------------------------------------------------------------
@@ -1292,8 +1292,9 @@ sub check_plugins {
 						($plugin_config_file) = split( /\s+/, $plugin_config_file);
 
-						# Skip parameters that start with '-', since those are probabably parameters, not config files.
+						# Skip parameters that start with '-' or 'proxy.config.', since those are probabably parameters, not config files.
 						last if $plugin_config_file =~ m/^-/; # Exit subblock.
This is an automated message from the Apache Git Service.
To respond to the message, please log on GitHub and use the
URL above to go to the specific comment.
 
For queries about this service, please contact Infrastructure at:
users@infra.apache.org


With regards,
Apache Git Services